Message

Struct Message 

pub struct Message { /* private fields */ }
A type for a message sent to an actor channel.

Note that this type uses an internal Arc so there is no reason to surround it with another Arc to make it thread safe.

Implementations

Source

impl Message

pub fn new<T>(value: T) -> Message
where T: 'static + ActorMessage,

Creates a new message from a value, transferring ownership to the message.

Examples
use axiom::message::Message;

let msg = Message::new(11);
pub fn from_arc<T>(value: Arc<T>) -> Message
where T: 'static + ActorMessage,

Creates a new message from an Arc, transferring ownership of the Arc to the message. Note that this is more efficient if a user wants to send a message that is already an Arc so they dont create an arc inside an Arc.

Examples
use axiom::message::Message;
use std::sync::Arc;

let arc = Arc::new(11);
let msg = Message::new(arc);
pub fn content_as<T>(&self) -> Option<Arc<T>>
where T: 'static + ActorMessage,

Get the content as an Arc<T>. If this fails a None will be returned. Note that the user need not worry whether the message came from a local or remote source as the heavy lifting for that is done internally. The first successful attempt to downcast a remote message will result in the value being converted to a local message.

Examples
use axiom::message::Message;
use std::sync::Arc;

let value = 11 as i32;
let msg = Message::new(value);
assert_eq!(value, *msg.content_as::<i32>().unwrap());
assert_eq!(None, msg.content_as::<u32>());